bayespy.inference.vmp.nodes.dirichlet.DirichletMoments
======================================================

.. currentmodule:: bayespy.inference.vmp.nodes.dirichlet

.. autoclass:: DirichletMoments

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~DirichletMoments.add_converter
      ~DirichletMoments.compute_dims_from_values
      ~DirichletMoments.compute_fixed_moments
      ~DirichletMoments.get_converter
   
   

   
   
   